﻿using System;
using System.IO;
using System.Runtime.InteropServices;

namespace CSV2HST
{
    /// <summary>
    /// Summary description for HST_Header.
    /// </summary>
    [StructLayout(LayoutKind.Sequential, Pack = 1)]
    public struct HST_HeaderRecord
    {
        public int Version;

        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 64)]
        public string Copyright;

        [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 12)]
        public string Symbol;

        public int Period;

        public int Digits;

        public int TimeSign_SecondsSince1970;

        public int LastSync_SecondsSince1970;

        [MarshalAs(UnmanagedType.ByValArray, SizeConst = 13)]
        public int[] Unused;

        public DateTime TimeSign
        {
            get { return new System.DateTime(1970, 1, 1).AddSeconds(this.TimeSign_SecondsSince1970); }
            set { this.TimeSign_SecondsSince1970 = (int)(value.Subtract(new System.DateTime(1970, 1, 1)).TotalSeconds); }
        }

        public DateTime TimeSync
        {
            get { return new System.DateTime(1970, 1, 1).AddSeconds(this.LastSync_SecondsSince1970); }
            set { this.LastSync_SecondsSince1970 = (int)(value.Subtract(new System.DateTime(1970, 1, 1)).TotalSeconds); }
        }

        public static HST_HeaderRecord GetHeader(string symbol)
        {
            HST_HeaderRecord header = new HST_HeaderRecord();
            header.Copyright = @"(C)opyright 2003, MetaQuotes Software Corp.";
            header.Digits = 5;
            header.Period = 1;
            header.Symbol = symbol;
            header.TimeSign = DateTime.Now;
            header.Unused = new int[13];
            header.Version = 400;
            return header;
        }
    }
}
