﻿using System;
using System.IO;
using System.Runtime.InteropServices;

namespace CSV2HST
{
    [StructLayout(LayoutKind.Sequential, Pack = 1)]
    public struct HST_RateInfoRecord
    {
        public int TimeStamp_SecondsSince1970;
        public double Open;
        public double Low;
        public double High;
        public double Close;
        public double Volume;

        public DateTime TimeStamp
        {
            get { return new System.DateTime(1970, 1, 1).AddSeconds(this.TimeStamp_SecondsSince1970); }
            set { this.TimeStamp_SecondsSince1970 = (int)(value.Subtract(new System.DateTime(1970, 1, 1)).TotalSeconds); } 
        }
        public int Minute
        {
            get { return (int)Math.Floor(this.TimeStamp_SecondsSince1970 / 60.0); }
        }

        public static HST_RateInfoRecord GetRateInfo(int minute, double rate)
        {
            HST_RateInfoRecord rateInfo = new HST_RateInfoRecord();
            rateInfo.TimeStamp_SecondsSince1970 = minute * 60;
            rateInfo.Open = rate;
            rateInfo.High = rate;
            rateInfo.Low = rate;
            rateInfo.Close = rate;
            rateInfo.Volume = 1;
            return rateInfo;
        }

        public static void UpdateRateInfo(ref HST_RateInfoRecord rateInfo, double rate)
        {
            rateInfo.Close = rate;

            if (rate > rateInfo.High)
                rateInfo.High = rate;

            if (rate < rateInfo.Low)
                rateInfo.High = rate;

            rateInfo.Volume++;
        }

    }
}
