﻿using System;
using System.Runtime.InteropServices;
using System.IO;
using System.Collections.Generic;
using LumenWorks.Framework.IO.Csv;

namespace CSV2HST
{
    public class Globals
    {
        public static int Main(string[] argv)
        {
            int argc = argv.Length; //Use this later for passing file names in

            //Create a HST file and put a header record in it
            FileStream fs = new FileStream(@"d:\temp\AUDNZD1.hst", FileMode.Create);
            MarshalHelper.Write<HST_HeaderRecord>(fs, HST_HeaderRecord.GetHeader("AUDNZD"));

            HST_RateInfoRecord rateInfo = new HST_RateInfoRecord();
            int riMinute = rateInfo.Minute;
            int minute = 0;
            double rate;
            double lastMinuteCloseRate;
            DateTime dt;

            //Get a sorted list of files of currency
            DirectoryInfo dir = new DirectoryInfo(@"D:\TICK_CSV\CSV");
            FileInfo[] files = dir.GetFiles("*AUD_NZD*.csv");

            SortedList<string, FileInfo> sortedFiles = new SortedList<string, FileInfo>(files.Length);
            foreach (FileInfo file in files)
                sortedFiles.Add(file.Name, file);

            //File format:
            //lTid,CurrencyPair,RateDateTime,Rate Bid,RateAsk,Dealable
            //354389687,AUD/NZD,2007-10-21 17:00:05.000,1.191200,1.192100,D
            //
            //Note: Sometimes the header is there and sometimes not.
            foreach (FileInfo file in sortedFiles.Values)
            {
                // open the file "data.csv" which is a CSV file with headers
                Console.Write(file.Name);
                using (CsvReader csv = new CsvReader(new StreamReader(file.FullName), false))
                {
                    int fieldCount = csv.FieldCount;

                    //process each record
                    while (csv.ReadNextRecord())
                    {
                        if (DateTime.TryParse(csv[2], out dt))
                        {
                            rate = double.Parse(csv[3]);
                            minute = (int)(dt.Subtract(new System.DateTime(1970, 1, 1)).TotalMinutes);
                            if (riMinute == minute)
                            {
                                HST_RateInfoRecord.UpdateRateInfo(ref rateInfo, rate);
                            }
                            else
                            {
                                if (riMinute != 0)
                                {
                                    MarshalHelper.Write<HST_RateInfoRecord>(fs, rateInfo);
                                    lastMinuteCloseRate = rateInfo.Close;
                                }
                                else
                                {
                                    lastMinuteCloseRate = rate;
                                }
                                rateInfo = HST_RateInfoRecord.GetRateInfo(minute, lastMinuteCloseRate);
                                riMinute = minute;
                            }
                        }
                    }
                }
                Console.WriteLine("...OK");
            }

            //long fsLength = -1; //Use to cache file length (improves performance)
            //long fsPosition = 0; //Use to cache current file position (improves performance)
            //int recordSize = 0; //Size of current struct to be read

            ////Open the file and cache the length
            //FileStream fs = new FileStream(@"d:\temp\AUDNZD1.hst", FileMode.Open, FileAccess.Read, FileShare.Read);
            //fsLength = fs.Length;
            //fsPosition = 0;

            ////Create a header variable and get the size
            //HST_HeaderRecord header;
            //recordSize = Marshal.SizeOf(typeof(HST_HeaderRecord));

            ////ensure that the end of the next record is within the file length ie testing for End of file
            ////Read the header from the file into our HST_HeaderRecord structure.
            //fsPosition += recordSize;
            //if (fsPosition <= fsLength)
            //    header = MarshalHelper.Read<HST_HeaderRecord>(fs);

            ////Create a RateInfo variable and get size
            //HST_RateInfoRecord rateInfo;
            //recordSize = Marshal.SizeOf(typeof(HST_RateInfoRecord));
            //int rateInfoRecordsCount = (int)((fsLength - fsPosition) / recordSize);
            //SortedList<DateTime, HST_RateInfoRecord> rateInfoCollection = new SortedList<DateTime, HST_RateInfoRecord>(rateInfoRecordsCount);

            ////ensure that the end of the next record is within the file length ie testing for End of file
            ////Read the RateInfo from the file into our HST_DataRecord structure.
            //fsPosition += recordSize;
            //while (fsPosition <= fsLength)
            //{
            //    rateInfo = MarshalHelper.Read<HST_RateInfoRecord>(fs);
            //    fsPosition += recordSize;
            //    try
            //    {
            //        rateInfoCollection.Add(rateInfo.TimeStamp, rateInfo);
            //    }
            //    catch (System.ArgumentException)
            //    {
            //        //Duplicate found
            //    }
            //}

            //Cleaning up
            fs.Close();
            fs = null;
            return 0;
        }
    }
}